==> anti-grian-switch-reborn-2.1.0-sources.jar: dev/gamelord2011/ags_reborn/AntiGrianSwitchReborn.java <==
package dev.gamelord2011.ags_reborn;

import net.fabricmc.api.ClientModInitializer;
import net.fabricmc.fabric.api.client.event.lifecycle.v1.ClientTickEvents;
//import net.minecraft.client.util.InputUtil;
import net.fabricmc.fabric.api.client.keybinding.v1.KeyBindingHelper;
import net.minecraft.class_304;
import net.minecraft.class_310;
import net.minecraft.class_3675;
import org.lwjgl.glfw.GLFW;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class AntiGrianSwitchReborn implements ClientModInitializer {
	public static final String MOD_ID = "anti-grian-switch-reborn";
    public static boolean enableFallingEntityBug = false;
    private static class_304 TGG;
    private static class_304 CCB;

	// This logger is used to write text to the console and the log file.
	// It is considered best practice to use your mod id as the logger's name.
	// That way, it's clear which mod wrote info, warnings, and errors.
	public static final Logger LOGGER = LoggerFactory.getLogger(MOD_ID);

    // Fabric API client entrypoint (if needed, move this to a ClientModInitializer class)
    public void onInitializeClient() {
        TGG = KeyBindingHelper.registerKeyBinding(new class_304(
            "Anti Grian Switch", // The translation key of the keybinding's name
            GLFW.GLFW_KEY_G, // The keycode of the key
            class_304.class_11900.field_62558
        ));

        CCB = KeyBindingHelper.registerKeyBinding(new class_304(
            "Should Control Be Held (AGS Reborn)(y/n)", // The translation key of the keybinding's name
            GLFW.GLFW_KEY_Y,
            class_304.class_11900.field_62558
        ));

        ClientTickEvents.END_CLIENT_TICK.register(client -> {
            if(KeyBindingHelper.getBoundKeyOf(CCB).method_1444() != GLFW.GLFW_KEY_N) {
                while (TGG.method_1436() && ((GLFW.glfwGetKey(client.method_22683().method_4490(), GLFW.GLFW_KEY_LEFT_CONTROL) == GLFW.GLFW_PRESS) || (GLFW.glfwGetKey(client.method_22683().method_4490(), GLFW.GLFW_KEY_RIGHT_CONTROL) == GLFW.GLFW_PRESS))) {
                    enableFallingEntityBug = !enableFallingEntityBug;
                    class_310.method_1551().field_1705.method_1743().method_1812(
                        net.minecraft.class_2561.method_43470(
                            "Anti Grian Switch: " + (AntiGrianSwitchReborn.enableFallingEntityBug ? "ON" : "OFF")
                        )
                    );
                }
            } else {
                if(KeyBindingHelper.getBoundKeyOf(CCB).method_1444() != GLFW.GLFW_KEY_Y) {
                    CCB.method_1422(class_3675.class_307.field_1668.method_1447(GLFW.GLFW_KEY_Y));
                }
                while (TGG.method_1436()) {
                    enableFallingEntityBug = !enableFallingEntityBug;
                    class_310.method_1551().field_1705.method_1743().method_1812(
                        net.minecraft.class_2561.method_43470(
                            "Anti Grian Switch: " + (AntiGrianSwitchReborn.enableFallingEntityBug ? "ON" : "OFF")
                        )
                    );
                }
            }
        });
    }
}

==> anti-grian-switch-reborn-2.1.2-sources.jar: dev/gamelord2011/ags_reborn/AntiGrianSwitchReborn.java <==
package dev.gamelord2011.ags_reborn;

import net.fabricmc.api.ClientModInitializer;
import net.fabricmc.fabric.api.client.event.lifecycle.v1.ClientTickEvents;
//import net.minecraft.client.util.InputUtil;
import net.fabricmc.fabric.api.client.keybinding.v1.KeyBindingHelper;
import net.minecraft.class_304;
import net.minecraft.class_310;
import net.minecraft.class_3675;
import org.lwjgl.glfw.GLFW;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class AntiGrianSwitchReborn implements ClientModInitializer {
	public static final String MOD_ID = "anti-grian-switch-reborn";
    public static boolean enableFallingEntityBug = false;
    private static class_304 TGG;
    private static class_304 CCB;

	// This logger is used to write text to the console and the log file.
	// It is considered best practice to use your mod id as the logger's name.
	// That way, it's clear which mod wrote info, warnings, and errors.
	public static final Logger LOGGER = LoggerFactory.getLogger(MOD_ID);

    // Fabric API client entrypoint (if needed, move this to a ClientModInitializer class)
    public void onInitializeClient() {
        TGG = KeyBindingHelper.registerKeyBinding(new class_304(
            "Anti Grian Switch", // The translation key of the keybinding's name
            GLFW.GLFW_KEY_G, // The keycode of the key
            class_304.class_11900.field_62558
        ));

        CCB = KeyBindingHelper.registerKeyBinding(new class_304(
            "Should Control Be Held (AGS Reborn)(y/n)", // The translation key of the keybinding's name
            GLFW.GLFW_KEY_Y,
            class_304.class_11900.field_62558
        ));

        ClientTickEvents.END_CLIENT_TICK.register(client -> {
            if(KeyBindingHelper.getBoundKeyOf(CCB).method_1444() == GLFW.GLFW_KEY_N) {
                while (TGG.method_1436() && ((GLFW.glfwGetKey(client.method_22683().method_4490(), GLFW.GLFW_KEY_LEFT_CONTROL) == GLFW.GLFW_PRESS) || (GLFW.glfwGetKey(client.method_22683().method_4490(), GLFW.GLFW_KEY_RIGHT_CONTROL) == GLFW.GLFW_PRESS))) {
                    enableFallingEntityBug = !enableFallingEntityBug;
                    class_310.method_1551().field_1705.method_1743().method_1812(
                        net.minecraft.class_2561.method_43470(
                            "Anti Grian Switch: " + (AntiGrianSwitchReborn.enableFallingEntityBug ? "ON" : "OFF")
                        )
                    );
                }
            } else {
                if(KeyBindingHelper.getBoundKeyOf(CCB).method_1444() != GLFW.GLFW_KEY_Y) {
                    CCB.method_1422(class_3675.class_307.field_1668.method_1447(GLFW.GLFW_KEY_Y));
                }
                while (TGG.method_1436()) {
                    enableFallingEntityBug = !enableFallingEntityBug;
                    class_310.method_1551().field_1705.method_1743().method_1812(
                        net.minecraft.class_2561.method_43470(
                            "Anti Grian Switch: " + (AntiGrianSwitchReborn.enableFallingEntityBug ? "ON" : "OFF")
                        )
                    );
                }
            }
        });
    }
}
